@@ -1,5 +1,5 @@
 package XML::Loy::XRD;
-use Mojo::JSON;
+use Mojo::JSON qw/encode_json decode_json/;
 use Mojo::Util 'quote';
 use Carp qw/carp/;
 use XML::Loy::Date::RFC3339;
@@ -81,7 +81,7 @@ sub alias {
 
     # Subject found
     my $sub = $self->find('Alias') or return;
-    return @{ $sub->pluck('text') };
+    return @{ $sub->map(sub { $_->text } ) };
   };
 
   # Add new alias
@@ -239,7 +239,7 @@ sub filter_rel {
   } @rel) : 'Link';
 
   # Remove unwanted link relations
-  $xrd->find($rel)->pluck('remove');
+  $xrd->find($rel)->map(sub { $_->remove });
   return $xrd;
 };
 
@@ -248,14 +248,13 @@ sub filter_rel {
 sub _to_xml {
   my $xrd = shift;
 
-  # Create new json object
-  my $json = Mojo::JSON->new;
-
   # Parse json document
-  my $jrd = $json->decode($_[0]);
+  my $jrd;
 
-  # There is a parsing error
-  carp $json->error unless $jrd;
+  # There may be a parsing error
+  eval {
+    $jrd = decode_json $_[0];
+  } or carp $@;
 
   # Itterate over all XRD elements
   foreach my $key (keys %$jrd) {
@@ -391,7 +390,7 @@ sub to_json {
       push(@links, \%link_prop);
     });
   $object{'links'} = \@links if @links;
-  return Mojo::JSON->new->encode(\%object);
+  return encode_json(\%object);
 };
 
 
